==> pygwalker-0.4.9a2.tar.gz: pygwalker-0.4.9a2/pygwalker/services/render.py <==
import os
import json
import base64
from typing import Dict, List, Any, Optional

from jinja2 import Environment, PackageLoader

from pygwalker._constants import ROOT_DIR
from pygwalker.utils.encode import DataFrameEncoder
from pygwalker.utils.estimate_tools import estimate_average_data_size

jinja_env = Environment(
    loader=PackageLoader("pygwalker"),
    autoescape=(()),  # select_autoescape()
)

with open(os.path.join(ROOT_DIR, 'templates', 'dist', 'pygwalker-app.iife.js'), 'r', encoding='utf8') as f:
    GWALKER_SCRIPT = f.read()
    GWALKER_SCRIPT_BASE64 = base64.b64encode(GWALKER_SCRIPT.encode()).decode()


def get_max_limited_datas(datas: List[Dict[str, Any]], byte_limit: int) -> List[Dict[str, Any]]:
    if len(datas) > 1024:
        avg_size = estimate_average_data_size(datas)
        n = int(byte_limit / avg_size)
        if len(datas) >= 2 * n:
            return datas[:n]
    return datas


def render_gwalker_iframe(
    gid: int,
    srcdoc: str,
    width: Optional[str] = None,
    height: Optional[str] = None
) -> str:
    if height is None:
        height = "960px"
    if width is None:
        width = "100%"

    return jinja_env.get_template("pygwalker_iframe.html").render(
        gid=gid,
        srcdoc=srcdoc,
        height=height,
        width=width
    )


def render_gwalker_html(gid: int, props: Dict[str, Any]) -> str:
    container_id = f"gwalker-div-{gid}"
    template = jinja_env.get_template("pygwalker_main_page.html")
    html = template.render(
        gwalker={
            'id': container_id,
            'gw_script': GWALKER_SCRIPT_BASE64,
            "component_script": "PyGWalkerApp.GWalker(props, gw_id);",
            "props": json.dumps(props, cls=DataFrameEncoder)
        }
    )
    return html

==> pygwalker-0.4.9.7.tar.gz: pygwalker-0.4.9.7/pygwalker/services/render.py <==
import os
import json
import base64
import html as m_html
from typing import Dict, List, Any, Optional

from jinja2 import Environment, PackageLoader

from pygwalker._typing import IAppearance
from pygwalker._constants import ROOT_DIR
from pygwalker.utils.encode import DataFrameEncoder
from pygwalker.utils.estimate_tools import estimate_average_data_size
from pygwalker.services.global_var import GlobalVarManager

jinja_env = Environment(
    loader=PackageLoader("pygwalker"),
    autoescape=(()),  # select_autoescape()
)

with open(os.path.join(ROOT_DIR, 'templates', 'dist', 'pygwalker-app.iife.js'), 'r', encoding='utf8') as f:
    GWALKER_SCRIPT = f.read()
    GWALKER_SCRIPT_BASE64 = base64.b64encode(GWALKER_SCRIPT.encode()).decode()


def get_max_limited_datas(datas: List[Dict[str, Any]], byte_limit: int) -> List[Dict[str, Any]]:
    if len(datas) > 1024:
        avg_size = estimate_average_data_size(datas)
        n = int(byte_limit / avg_size)
        if len(datas) >= 2 * n:
            return datas[:n]
    return datas


def render_iframe_messages_html(gid: str) -> str:
    return jinja_env.get_template("jupyter_iframe_message.html").render(gid=gid)


def render_gwalker_iframe(
    gid: int,
    html: str,
    width: Optional[str] = None,
    height: Optional[str] = None,
    appearance: IAppearance = "media",
) -> str:
    if height is None:
        height = "960px"
    if width is None:
        width = "100%"

    return jinja_env.get_template("pygwalker_iframe.html").render(
        gid=gid,
        srcdoc=m_html.escape(html),
        height=height,
        width=width,
        appearance=appearance,
        component_url=GlobalVarManager.component_url
    )


def render_gwalker_html(gid: int, props: Dict[str, Any]) -> str:
    container_id = f"gwalker-div-{gid}"
    template = jinja_env.get_template("pygwalker_main_page.html")
    html = template.render(
        gwalker={
            'id': container_id,
            'gw_script': GWALKER_SCRIPT_BASE64,
            "component_script": "PyGWalkerApp.GWalker(props, gw_id);",
            "props": json.dumps(props, cls=DataFrameEncoder)
        },
        component_url=GlobalVarManager.component_url
    )
    return html
